@@ -1,6 +1,6 @@
 /* otfdump.c -- Dump OpenType Layout Tables.
 
-Copyright (C) 2003, 2004
+Copyright (C) 2003, 2004, 2008
   National Institute of Advanced Industrial Science and Technology (AIST)
   Registration Number H15PRO167
 
@@ -306,10 +306,14 @@ dump_device_table (int indent, char *title, OTF_DeviceTable *table)
   indent++;
   IPRINT ("(StartSize %d) (EndSize %d) (DeltaFormat %d)",
 	  table->StartSize, table->EndSize, table->DeltaFormat);
-  IPRINT ("(DeltaValue");
-  for (i = 0; i < table->EndSize - table->StartSize + 1; i++)
-    printf (" %d", table->DeltaValue[i]);
-  printf ("))");
+  if (table->DeltaValue)
+    {
+      IPRINT ("(DeltaValue");
+      for (i = 0; i < table->EndSize - table->StartSize + 1; i++)
+	printf (" %d", table->DeltaValue[i]);
+      printf (")");
+    }
+  printf (")");
 }
 
 
@@ -711,13 +715,14 @@ dump_chain_class_set_list (int indent, OTF_ChainClassSet *set, int count)
 
   IPRINT ("(ChainClassSetCount %d)", count);
   for (i = 0; i < count; i++)
-    {
-      IPRINT ("(ChainClassSet (%d)", i);
-      dump_chain_class_rule_list (indent + 1,
-				  set[i].ChainClassRule,
-				  set[i].ChainClassRuleCnt);
-      printf (")");
-    }
+    if (set[i].offset)
+      {
+	IPRINT ("(ChainClassSet (%d)", i);
+	dump_chain_class_rule_list (indent + 1,
+				    set[i].ChainClassRule,
+				    set[i].ChainClassRuleCnt);
+	printf (")");
+      }
 }
 
 
