@@ -83,7 +83,7 @@ print_gsub_gpos_info (OTF *otf, char *table)
 		    printf (", ");
 		  print_tag (script->LangSysRecord[j].LangSysTag);
 		}
-	      printf (" )");
+	      printf (")");
 	    }
 	}
       printf ("\n");
@@ -119,6 +119,8 @@ filter (const struct dirent *direntry)
   return (len >= 5
 	  && (! strncmp (ext, ".ttf", 4)
 	      || ! strncmp (ext, ".TTF", 4)
+	      || ! strncmp (ext, ".ttc", 4)
+	      || ! strncmp (ext, ".TTC", 4)
 	      || ! strncmp (ext, ".otf", 4)
 	      || ! strncmp (ext, ".OTF", 4)
 	      || ! strncmp (ext, ".PFA", 4)
@@ -179,8 +181,7 @@ main (int argc, char **argv)
   FT_Face face;
   char *filename;
   int long_format = 0;
-  int n;
-  int i, j;
+  int i;
 
   if (FT_Init_FreeType (&ft_library))
     FATAL_ERROR ("%s\n", "!! Freetype initialization failed.");
@@ -224,9 +225,9 @@ main (int argc, char **argv)
 			 + 4);
 	  sprintf (name, "%s (%s)", filename, family);
 	  printf ("%-40s %s", name, style);
-	  for (j = 0; j < face->num_charmaps; j++)
-	    printf (" %d-%d", face->charmaps[j]->platform_id,
-		    face->charmaps[j]->encoding_id);
+	  for (i = 0; i < face->num_charmaps; i++)
+	    printf (" %d-%d", face->charmaps[i]->platform_id,
+		    face->charmaps[i]->encoding_id);
 	  printf ("\n");
 	  if (otf && long_format)
 	    {
