@@ -1,6 +1,6 @@
 /* otfview.c -- View glyphs of OpenType fonts.
 
-Copyright (C) 2003, 2004, 2005, 2006
+Copyright (C) 2003, 2004, 2005, 2006, 2008
   National Institute of Advanced Industrial Science and Technology (AIST)
   Registration Number H15PRO167
 
@@ -268,9 +268,10 @@ get_features (OTF_FeatureList *list, FeatureRec *rec)
 }
 
 
-#define DEVICE_DELTA(table, size)				\
-  (((size) >= (table).StartSize && (size) <= (table).EndSize)	\
-   ? (table).DeltaValue[(size) >= (table).StartSize]		\
+#define DEVICE_DELTA(table, size)					\
+  (((table).DeltaValue							\
+    && ((size) >= (table).StartSize && (size) <= (table).EndSize))	\
+   ? (table).DeltaValue[(size) >= (table).StartSize]			\
    : 0)
 
 void
